Ranma 1∕2 (2024) 2nd Season - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# Ranma 1∕2 (2024) 2nd Season

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%5BNanakoRaws%5D%20Ranma%20%C2%BD%20%282024%29%20S2%20-%2002%20%28ytv%201920x1080%20x265%20AAC%29.sdh.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%E3%82%89%E3%82%93%E3%81%BE1%202.S02E14.%E3%80%8C%E3%83%A0%E3%83%BC%E3%82%B9%E8%A5%B2%E6%9D%A5%E3%80%8D.WEBRip.Netflix.ja%5Bcc%5D.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | [NanakoRaws] Ranma ½ (2024) S2 - 02 (ytv 1920x1080 x265 AAC).sdh.srt | 5.00 B | 15 Dec 2025 07:14:26
2 | らんま1 2.S02E14.「ムース襲来」.WEBRip.Netflix.ja[cc].srt | 6.00 B | 15 Dec 2025 07:14:33

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%5BErai-raws%5D%20Ranma%201%202%20%282024%29%202nd%20Season%20-%2001%20%5B1080p%20NF%20WEB-DL%20AVC%20AAC%5D%5BJPN%5D%5B8FC0C2D2%5D.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%5BNekomoe%20kissaten%26LoliHouse%5D%20Ranma%20%C2%BD%202024%20-%2014%20%5BWebRip%201080p%20HEVC-10bit%20AAC%20ASSx2%5D%5BCHS%2C%20JPN%5D.ass'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | [Erai-raws] Ranma 1 2 (2024) 2nd Season - 01 [1080p NF WEB-DL AVC AAC][JPN][8FC0C2D2].ass | 6.00 B | 15 Dec 2025 07:14:22
2 | [Nekomoe kissaten&LoliHouse] Ranma ½ 2024 - 14 [WebRip 1080p HEVC-10bit AAC ASSx2][CHS, JPN].ass | 6.00 B | 15 Dec 2025 07:14:30

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%5BErai-raws%5D%20Ranma%201%202%20%282024%29%202nd%20Season%20-%2001%20%5B1080p%20NF%20WEB-DL%20AVC%20AAC%5D%5BJPN%5D%5B8FC0C2D2%5D.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%5BNanakoRaws%5D%20Ranma%20%C2%BD%20%282024%29%20S2%20-%2002%20%28ytv%201920x1080%20x265%20AAC%29.sdh.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%5BNekomoe%20kissaten%26LoliHouse%5D%20Ranma%20%C2%BD%202024%20-%2014%20%5BWebRip%201080p%20HEVC-10bit%20AAC%20ASSx2%5D%5BCHS%2C%20JPN%5D.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/anime_tv/Ranma%201%E2%88%952%20%282024%29%202nd%20Season/%E3%82%89%E3%82%93%E3%81%BE1%202.S02E14.%E3%80%8C%E3%83%A0%E3%83%BC%E3%82%B9%E8%A5%B2%E6%9D%A5%E3%80%8D.WEBRip.Netflix.ja%5Bcc%5D.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | [Erai-raws] Ranma 1 2 (2024) 2nd Season - 01 [1080p NF WEB-DL AVC AAC][JPN][8FC0C2D2].ass | 6.00 B | 15 Dec 2025 07:14:22
2 | [NanakoRaws] Ranma ½ (2024) S2 - 02 (ytv 1920x1080 x265 AAC).sdh.srt | 5.00 B | 15 Dec 2025 07:14:26
3 | [Nekomoe kissaten&LoliHouse] Ranma ½ 2024 - 14 [WebRip 1080p HEVC-10bit AAC ASSx2][CHS, JPN].ass | 6.00 B | 15 Dec 2025 07:14:30
4 | らんま1 2.S02E14.「ムース襲来」.WEBRip.Netflix.ja[cc].srt | 6.00 B | 15 Dec 2025 07:14:33

Upload new files — Search MAL — Back to Index